@@ -33,6 +33,14 @@ class cjdgUser(base):
 
         return self.request(api_name, data)
 
+    def read_by_tel(self, tel):
+        # 为啥同步不过去
+        api_name = "user/query"
+        data = {
+            "tel": tel,
+        }
+        return self.request(api_name, data)
+
     def getUserIds(self, accounts):
         api_name = "user/query/byaccounts"
         data = {
