@@ -10,12 +10,12 @@ class cjdgUserGroup(base):
     def operation(self, operationType, groupName, accounts=None):
         data = {
             "operationType": operationType,
-            "groupName": group_name,
+            "groupName": groupName,
         }
         if accounts:
             data["accounts"] = accounts
         api_name = "user/operationGroupUser"
-        return self.request((api_name, data))
+        return self.request(api_name, data)
 
     def add(self, group_name, login_name):
         data = {
